@@ -1,5 +1,5 @@
 /*
- * $Id: libcap.h,v 1.2 1997/04/28 00:57:11 morgan Exp morgan $
+ * $Id: libcap.h,v 1.2 1999/04/17 23:25:10 morgan Exp $
  *
  * Copyright (c) 1997 Andrew G Morgan <morgan@linux.kernel.org>
  *
@@ -12,12 +12,21 @@
 #ifndef LIBCAP_H
 #define LIBCAP_H
 
+#include <sys/types.h>
 #include <errno.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <sys/capability.h>
 
+#ifndef __u8
+#define __u8    unsigned char
+#endif /* __8 */
+
+#ifndef __u32
+#define __u32   unsigned int
+#endif /* __u32 */
+
 /* include the names for the caps and a definition of __CAP_BITS */
 #include "cap_names.h"
 
@@ -33,8 +42,8 @@
 #define CAP_T_MAGIC 0xCA90D0
 struct _cap_struct {
     int magic;
-    struct _user_cap_header_struct head;
-    struct _user_cap_data_struct set;
+    struct __user_cap_header_struct head;
+    struct __user_cap_data_struct set;
 };
 
 /*
@@ -54,13 +63,13 @@ struct _cap_struct {
  */
 
 #define NUMBER_OF_CAP_SETS      3   /* effective, inheritable, permitted */
-#define CAP_SET_SIZE  (sizeof(struct _user_cap_data_struct)/NUMBER_OF_CAP_SETS)
+#define CAP_SET_SIZE (sizeof(struct __user_cap_data_struct)/NUMBER_OF_CAP_SETS)
 #define __CAP_BLKS   (CAP_SET_SIZE/sizeof(__u32))
 typedef struct {
     __u32 _blk[__CAP_BLKS];
 } __cap_s;
 #define raise_cap(x)   _blk[(x)>>5] |= (1<<((x)&31))
-#define lower_cap(x)   _blk[(x)>>5] |= (1<<((x)&31))
+#define lower_cap(x)   _blk[(x)>>5] &= ~(1<<((x)&31))
 #define isset_cap(y,x) ((y)->_blk[(x)>>5] & (1<<((x)&31)))
 
 /*
@@ -106,6 +115,21 @@ extern int capsetp(pid_t pid, cap_t cap_d);
 
 /*
  * $Log: libcap.h,v $
+ * Revision 1.2  1999/04/17 23:25:10  morgan
+ * fixes from peeterj
+ *
+ * Revision 1.1.1.1  1999/04/17 22:16:31  morgan
+ * release 1.0 of libcap
+ *
+ * Revision 1.5  1998/06/08 00:15:28  morgan
+ * accommodate alpha (glibc?)
+ *
+ * Revision 1.4  1998/06/07 15:58:23  morgan
+ * accommodate real kernel header files :*)
+ *
+ * Revision 1.3  1998/05/24 22:54:09  morgan
+ * updated for 2.1.104
+ *
  * Revision 1.2  1997/04/28 00:57:11  morgan
  * zefram's replacement file with a number of bug fixes from AGM
  *
